# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: perc.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import coord_pb2 as coord__pb2
from . import uuid_pb2 as uuid__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\nperc.proto\x1a\x0b\x63oord.proto\x1a\nuuid.proto\"]\n\rPercPersonFer\x12\x0f\n\x07neutral\x18\x01 \x01(\x02\x12\r\n\x05happy\x18\x02 \x01(\x02\x12\x0b\n\x03sad\x18\x03 \x01(\x02\x12\x10\n\x08surprise\x18\x04 \x01(\x02\x12\r\n\x05\x61nger\x18\x05 \x01(\x02\"\x98\x01\n\x0cPercPersonLm\x12\x19\n\x05\x65ye_l\x18\x01 \x01(\x0b\x32\n.CPoint2dS\x12\x19\n\x05\x65ye_r\x18\x02 \x01(\x0b\x32\n.CPoint2dS\x12\x18\n\x04nose\x18\x03 \x01(\x0b\x32\n.CPoint2dS\x12\x1b\n\x07mouth_l\x18\x04 \x01(\x0b\x32\n.CPoint2dS\x12\x1b\n\x07mouth_r\x18\x05 \x01(\x0b\x32\n.CPoint2dS\"\xf3\x02\n\nPercPerson\x12\x10\n\x08id_score\x18\x02 \x01(\x02\x12\x13\n\x04uuid\x18\x0f \x01(\x0b\x32\x05.Uuid\x12\x17\n\x04\x66\x61\x63\x65\x18\x03 \x01(\x0b\x32\t.CBbox2dS\x12\x19\n\x02lm\x18\x04 \x01(\x0b\x32\r.PercPersonLm\x12\x14\n\x02hp\x18\x05 \x01(\x0b\x32\x08.CBryanS\x12\x1a\n\x04gaze\x18\x06 \x01(\x0b\x32\x0c.CCartVec3dS\x12\x1b\n\x03\x66\x65r\x18\x07 \x01(\x0b\x32\x0e.PercPersonFer\x12\x0f\n\x07\x64ist_mm\x18\x08 \x01(\x02\x12\x14\n\x0cgaze_overlap\x18\t \x01(\x02\x12\x1d\n\x07g_eye_l\x18\n \x03(\x0b\x32\x0c.CCartSys3dS\x12\x1d\n\x07g_eye_r\x18\x0b \x03(\x0b\x32\x0c.CCartSys3dS\x12\x1c\n\x06g_nose\x18\x0c \x03(\x0b\x32\x0c.CCartSys3dS\x12\x1a\n\x04g_hp\x18\r \x03(\x0b\x32\x0c.CCartSys3dS\x12\x1c\n\x06g_gaze\x18\x0e \x03(\x0b\x32\x0c.CCartSys3dS\"\'\n\nPercObject\x12\x19\n\x03loc\x18\x01 \x01(\x0b\x32\x0c.CCartVec3dS\"Z\n\x0bPercSstMeta\x12\n\n\x02id\x18\x01 \x01(\x04\x12\x10\n\x08\x61\x63tivity\x18\x02 \x01(\x02\x12\x19\n\x03loc\x18\x03 \x01(\x0b\x32\x0c.CCartSys3dS\x12\x12\n\nis_dynamic\x18\x04 \x01(\x08\"\x9d\x01\n\x08PercData\x12\x0c\n\x04time\x18\x01 \x01(\x04\x12\r\n\x05\x66lags\x18\x02 \x01(\r\x12\x19\n\x04pers\x18\x03 \x03(\x0b\x32\x0b.PercPerson\x12\x18\n\x03obj\x18\x04 \x03(\x0b\x32\x0b.PercObject\x12\x17\n\x0fsst_time_latest\x18\x05 \x01(\x04\x12&\n\x10sst_track_latest\x18\x06 \x03(\x0b\x32\x0c.PercSstMetaB\nZ\x08./;protob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'perc_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\010./;proto'
  _PERCPERSONFER._serialized_start=39
  _PERCPERSONFER._serialized_end=132
  _PERCPERSONLM._serialized_start=135
  _PERCPERSONLM._serialized_end=287
  _PERCPERSON._serialized_start=290
  _PERCPERSON._serialized_end=661
  _PERCOBJECT._serialized_start=663
  _PERCOBJECT._serialized_end=702
  _PERCSSTMETA._serialized_start=704
  _PERCSSTMETA._serialized_end=794
  _PERCDATA._serialized_start=797
  _PERCDATA._serialized_end=954
# @@protoc_insertion_point(module_scope)
