# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: uuid.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\nuuid.proto\"6\n\x04Uuid\x12\n\n\x02\x63\x30\x18\x01 \x01(\x07\x12\n\n\x02\x63\x31\x18\x02 \x01(\x07\x12\n\n\x02\x63\x32\x18\x03 \x01(\x07\x12\n\n\x02\x63\x33\x18\x04 \x01(\x07\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'uuid_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _UUID._serialized_start=14
  _UUID._serialized_end=68
# @@protoc_insertion_point(module_scope)
