# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: coord.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0b\x63oord.proto\".\n\x0b\x43\x43\x61rtVec3dS\x12\t\n\x01x\x18\x01 \x01(\x02\x12\t\n\x01y\x18\x02 \x01(\x02\x12\t\n\x01z\x18\x03 \x01(\x02\":\n\x08\x43\x42\x62ox2dS\x12\n\n\x02x1\x18\x01 \x01(\x05\x12\n\n\x02y1\x18\x02 \x01(\x05\x12\n\n\x02x2\x18\x03 \x01(\x05\x12\n\n\x02y2\x18\x04 \x01(\x05\"!\n\tCPoint2dS\x12\t\n\x01x\x18\x01 \x01(\x05\x12\t\n\x01y\x18\x02 \x01(\x05\"*\n\x07\x43\x42ryanS\x12\t\n\x01x\x18\x01 \x01(\x02\x12\t\n\x01y\x18\x02 \x01(\x02\x12\t\n\x01z\x18\x03 \x01(\x02\"I\n\x0b\x43\x43\x61rtSys3dS\x12\x19\n\x03sys\x18\x01 \x01(\x0e\x32\x0c.CoordSystem\x12\t\n\x01x\x18\x02 \x01(\x02\x12\t\n\x01y\x18\x03 \x01(\x02\x12\t\n\x01z\x18\x04 \x01(\x02*\x95\x01\n\x0b\x43oordSystem\x12\r\n\tUNDEFINED\x10\x00\x12\r\n\tCAM_CHEST\x10\x01\x12\x0c\n\x08HEAD_REF\x10\x02\x12\x11\n\rHEAD_STRAIGHT\x10\x03\x12\r\n\tHEAD_REAL\x10\x04\x12\x0c\n\x08\x43\x41M_HEAD\x10\x05\x12\t\n\x05\x45YE_L\x10\x06\x12\t\n\x05\x45YE_R\x10\x07\x12\x14\n\x10\x43OORD_SYSTEM_LEN\x10\x08\x42\nZ\x08./;protob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'coord_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\010./;proto'
  _COORDSYSTEM._serialized_start=278
  _COORDSYSTEM._serialized_end=427
  _CCARTVEC3DS._serialized_start=15
  _CCARTVEC3DS._serialized_end=61
  _CBBOX2DS._serialized_start=63
  _CBBOX2DS._serialized_end=121
  _CPOINT2DS._serialized_start=123
  _CPOINT2DS._serialized_end=156
  _CBRYANS._serialized_start=158
  _CBRYANS._serialized_end=200
  _CCARTSYS3DS._serialized_start=202
  _CCARTSYS3DS._serialized_end=275
# @@protoc_insertion_point(module_scope)
