# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: config.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0c\x63onfig.proto\"\xe0\x03\n\x12\x43onfigGetDescEntry\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x19\n\x04type\x18\x02 \x01(\x0e\x32\x0b.ConfigType\x12\x11\n\x07min_i32\x18\x03 \x01(\x05H\x00\x12\x11\n\x07min_u32\x18\x04 \x01(\rH\x00\x12\x11\n\x07min_i64\x18\x05 \x01(\x03H\x00\x12\x11\n\x07min_u64\x18\x06 \x01(\x04H\x00\x12\x11\n\x07min_f32\x18\x07 \x01(\x02H\x00\x12\x11\n\x07min_f64\x18\x08 \x01(\x01H\x00\x12\x11\n\x07max_i32\x18\t \x01(\x05H\x01\x12\x11\n\x07max_u32\x18\n \x01(\rH\x01\x12\x11\n\x07max_i64\x18\x0b \x01(\x03H\x01\x12\x11\n\x07max_u64\x18\x0c \x01(\x04H\x01\x12\x11\n\x07max_f32\x18\r \x01(\x02H\x01\x12\x11\n\x07max_f64\x18\x0e \x01(\x01H\x01\x12\x15\n\x0b\x64\x65\x66_val_i32\x18\x0f \x01(\x05H\x02\x12\x15\n\x0b\x64\x65\x66_val_u32\x18\x10 \x01(\rH\x02\x12\x15\n\x0b\x64\x65\x66_val_i64\x18\x11 \x01(\x03H\x02\x12\x15\n\x0b\x64\x65\x66_val_u64\x18\x12 \x01(\x04H\x02\x12\x15\n\x0b\x64\x65\x66_val_f32\x18\x13 \x01(\x02H\x02\x12\x15\n\x0b\x64\x65\x66_val_f64\x18\x14 \x01(\x01H\x02\x12\r\n\x05\x66lags\x18\x15 \x01(\r\x12\x0b\n\x03len\x18\x16 \x01(\rB\x05\n\x03minB\x05\n\x03maxB\t\n\x07\x64\x65\x66_val\"1\n\rConfigGetDesc\x12 \n\x03\x63\x66g\x18\x01 \x03(\x0b\x32\x13.ConfigGetDescEntry\"\x1e\n\nConfigSave\x12\x10\n\x08\x66ilename\x18\x01 \x01(\t*U\n\x10\x43onfigTypeOffset\x12\r\n\tundefined\x10\x00\x12\x0e\n\nmin_offset\x10\x03\x12\x0e\n\nmax_offset\x10\t\x12\x12\n\x0e\x64\x65\x66_val_offset\x10\x0f*Y\n\nConfigType\x12\x0b\n\x07int32_t\x10\x00\x12\x0c\n\x08uint32_t\x10\x01\x12\x0b\n\x07int64_t\x10\x02\x12\x0c\n\x08uint64_t\x10\x03\x12\t\n\x05\x66loat\x10\x04\x12\n\n\x06\x64ouble\x10\x05\x42\nZ\x08./;protob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'config_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\010./;proto'
  _CONFIGTYPEOFFSET._serialized_start=582
  _CONFIGTYPEOFFSET._serialized_end=667
  _CONFIGTYPE._serialized_start=669
  _CONFIGTYPE._serialized_end=758
  _CONFIGGETDESCENTRY._serialized_start=17
  _CONFIGGETDESCENTRY._serialized_end=497
  _CONFIGGETDESC._serialized_start=499
  _CONFIGGETDESC._serialized_end=548
  _CONFIGSAVE._serialized_start=550
  _CONFIGSAVE._serialized_end=580
# @@protoc_insertion_point(module_scope)
