# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: payload.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import coord_pb2 as coord__pb2
from . import uuid_pb2 as uuid__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rpayload.proto\x1a\x0b\x63oord.proto\x1a\nuuid.proto\"\x15\n\x06Strmsg\x12\x0b\n\x03str\x18\x01 \x01(\t\"6\n\nLookatCart\x12\x1a\n\x04\x63\x61rt\x18\x01 \x01(\x0b\x32\x0c.CCartSys3dS\x12\x0c\n\x04head\x18\x02 \x01(\x02\"0\n\x08LookatPx\x12\x16\n\x02px\x18\x01 \x01(\x0b\x32\n.CPoint2dS\x12\x0c\n\x04head\x18\x02 \x01(\x02\"1\n\x0cLookatPerson\x12\x13\n\x04uuid\x18\x01 \x01(\x0b\x32\x05.Uuid\x12\x0c\n\x04head\x18\x02 \x01(\x02\"8\n\tHeadBndry\x12\r\n\x05v_max\x18\x01 \x01(\x02\x12\r\n\x05\x61_max\x18\x02 \x01(\x02\x12\r\n\x05j_max\x18\x03 \x01(\x02\"(\n\x0bHeadOverlay\x12\x19\n\x07overlay\x18\x01 \x01(\x0b\x32\x08.CBryanS\"e\n\x06HeadFe\x12\x0f\n\x07neutral\x18\x01 \x01(\x02\x12\r\n\x05happy\x18\x02 \x01(\x02\x12\x0b\n\x03sad\x18\x03 \x01(\x02\x12\x10\n\x08surprise\x18\x04 \x01(\x02\x12\r\n\x05\x61nger\x18\x05 \x01(\x02\x12\r\n\x05smile\x18\x06 \x01(\x02\"5\n\x0bHeadEyelids\x12\x12\n\nopenness_l\x18\x01 \x01(\x02\x12\x12\n\nopenness_r\x18\x02 \x01(\x02\"\x1d\n\tHeadMouth\x12\x10\n\x08openness\x18\x01 \x01(\x02\"|\n\tConfigSet\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x03i32\x18\x02 \x01(\x05H\x00\x12\r\n\x03u32\x18\x03 \x01(\rH\x00\x12\r\n\x03i64\x18\x04 \x01(\x03H\x00\x12\r\n\x03u64\x18\x05 \x01(\x04H\x00\x12\r\n\x03\x66\x33\x32\x18\x06 \x01(\x02H\x00\x12\r\n\x03\x66\x36\x34\x18\x07 \x01(\x01H\x00\x42\x07\n\x05value\"*\n\x07\x42\x61seinc\x12\t\n\x01x\x18\x01 \x01(\x05\x12\t\n\x01y\x18\x02 \x01(\x05\x12\t\n\x01z\x18\x03 \x01(\x05\" \n\x08\x42\x61setilt\x12\t\n\x01x\x18\x01 \x01(\x05\x12\t\n\x01y\x18\x02 \x01(\x05\"(\n\x04\x41rms\x12\x0f\n\x07\x61ngle_l\x18\x01 \x01(\x05\x12\x0f\n\x07\x61ngle_r\x18\x02 \x01(\x05\x42\nZ\x08./;protob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'payload_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\010./;proto'
  _STRMSG._serialized_start=42
  _STRMSG._serialized_end=63
  _LOOKATCART._serialized_start=65
  _LOOKATCART._serialized_end=119
  _LOOKATPX._serialized_start=121
  _LOOKATPX._serialized_end=169
  _LOOKATPERSON._serialized_start=171
  _LOOKATPERSON._serialized_end=220
  _HEADBNDRY._serialized_start=222
  _HEADBNDRY._serialized_end=278
  _HEADOVERLAY._serialized_start=280
  _HEADOVERLAY._serialized_end=320
  _HEADFE._serialized_start=322
  _HEADFE._serialized_end=423
  _HEADEYELIDS._serialized_start=425
  _HEADEYELIDS._serialized_end=478
  _HEADMOUTH._serialized_start=480
  _HEADMOUTH._serialized_end=509
  _CONFIGSET._serialized_start=511
  _CONFIGSET._serialized_end=635
  _BASEINC._serialized_start=637
  _BASEINC._serialized_end=679
  _BASETILT._serialized_start=681
  _BASETILT._serialized_end=713
  _ARMS._serialized_start=715
  _ARMS._serialized_end=755
# @@protoc_insertion_point(module_scope)
