# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sys.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\tsys.proto\"u\n\x0bSystemState\x12\x10\n\x08\x61gx_mode\x18\x01 \x01(\r\x12\x11\n\tbattery_u\x18\x02 \x01(\x05\x12\x15\n\rbattery_chg_i\x18\x03 \x01(\x05\x12\x13\n\x0bis_charging\x18\x04 \x01(\x08\x12\x15\n\rbattery_level\x18\x05 \x01(\x02\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sys_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SYSTEMSTATE._serialized_start=13
  _SYSTEMSTATE._serialized_end=130
# @@protoc_insertion_point(module_scope)
