# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: klframe.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rklframe.proto\".\n\x07Klframe\x12\x15\n\x05ptype\x18\x01 \x01(\x0e\x32\x06.Ptype\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c*\x91\x03\n\x05Ptype\x12\n\n\x06STRMSG\x10\x00\x12\x08\n\x04PERC\x10\x01\x12\x0f\n\x0bLOOKAT_CART\x10\x04\x12\r\n\tLOOKAT_PX\x10\x05\x12\x11\n\rLOOKAT_PERSON\x10\x06\x12\x10\n\x0cHEAD_OVERLAY\x10\x07\x12\x0b\n\x07HEAD_FE\x10\x08\x12\x10\n\x0cHEAD_EYELIDS\x10\t\x12\x0e\n\nHEAD_MOUTH\x10\n\x12\x0e\n\nCONFIG_SET\x10\x0b\x12\x13\n\x0f\x43ONFIG_GET_DESC\x10\x0c\x12\x0e\n\nCONFIG_GET\x10\r\x12\x0f\n\x0b\x43ONFIG_SAVE\x10\x0e\x12\x0f\n\x0bSPEECH_TEXT\x10\x0f\x12\x14\n\x10SPEECH_ASR_STATE\x10\x10\x12\x0b\n\x07\x42\x41SEINC\x10\x11\x12\x0c\n\x08\x42\x41SETILT\x10\x12\x12\x08\n\x04\x41RMS\x10\x13\x12\x13\n\x0fSPEECH_BOOKMARK\x10\x14\x12\x0e\n\nHEAD_BNDRY\x10\x15\x12\x10\n\x0cSYSTEM_STATE\x10\x16\x12\r\n\tPTYPE_LEN\x10\x17\"\x04\x08\x02\x10\x02\"\x04\x08\x03\x10\x03*\rNLDRIVE_STATE*\x0bNLDRIVE_CMDB\nZ\x08./;protob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'klframe_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\010./;proto'
  _PTYPE._serialized_start=66
  _PTYPE._serialized_end=467
  _KLFRAME._serialized_start=17
  _KLFRAME._serialized_end=63
# @@protoc_insertion_point(module_scope)
