# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: speech.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0cspeech.proto\"\x1c\n\nSpeechText\x12\x0e\n\x06speech\x18\x01 \x01(\t\"*\n\x0eSpeechAsrState\x12\x18\n\x10speaker_duration\x18\x01 \x01(\r\"\"\n\x0eSpeechBookmark\x12\x10\n\x08\x62ookmark\x18\x01 \x01(\rB\nZ\x08./;protob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'speech_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z\010./;proto'
  _SPEECHTEXT._serialized_start=16
  _SPEECHTEXT._serialized_end=44
  _SPEECHASRSTATE._serialized_start=46
  _SPEECHASRSTATE._serialized_end=88
  _SPEECHBOOKMARK._serialized_start=90
  _SPEECHBOOKMARK._serialized_end=124
# @@protoc_insertion_point(module_scope)
